# Projects

::: harborapi.client.HarborAsyncClient
    options:
        members:
        - get_project
        - create_project
        - update_project
        - delete_project
        - get_projects
        - get_project_logs
        - get_project_summary
        - project_exists
        - set_project_scanner
        - get_project_scanner
        - get_project_scanner_candidates
